@@ -1,7 +1,9 @@
 from __future__ import absolute_import, division, print_function
 
+import os
 
 import pytest
+from hypothesis import settings
 
 
 @pytest.fixture(scope="session")
@@ -17,3 +19,7 @@ def C():
         y = attr()
 
     return C
+
+# PyPy on Travis appears to be too slow.
+settings.register_profile("travis_pypy", settings(perform_health_check=False))
+settings.load_profile(os.getenv(u'HYPOTHESIS_PROFILE', 'default'))
